aboutsummaryrefslogtreecommitdiff
path: root/contrib/ntp/ntpdc/ntpdc-opts.c
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/ntp/ntpdc/ntpdc-opts.c')
-rw-r--r--contrib/ntp/ntpdc/ntpdc-opts.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/contrib/ntp/ntpdc/ntpdc-opts.c b/contrib/ntp/ntpdc/ntpdc-opts.c
index f2fde352b5a6..536d1b970f98 100644
--- a/contrib/ntp/ntpdc/ntpdc-opts.c
+++ b/contrib/ntp/ntpdc/ntpdc-opts.c
@@ -1,7 +1,7 @@
/*
* EDIT THIS FILE WITH CAUTION (ntpdc-opts.c)
*
- * It has been AutoGen-ed May 31, 2023 at 02:49:46 PM by AutoGen 5.18.16
+ * It has been AutoGen-ed June 6, 2023 at 04:37:53 AM by AutoGen 5.18.16
* From the definitions ntpdc-opts.def
* and the template file options
*
@@ -74,7 +74,7 @@ extern FILE * option_usage_fp;
* static const strings for ntpdc options
*/
static char const ntpdc_opt_strs[2005] =
-/* 0 */ "ntpdc 4.2.8p16\n"
+/* 0 */ "ntpdc 4.2.8p17\n"
"Copyright (C) 1992-2023 The University of Delaware and Network Time Foundation, all rights reserved.\n"
"This is free software. It is licensed for use, modification and\n"
"redistribution under the terms of the NTP License, copies of which\n"
@@ -136,14 +136,14 @@ static char const ntpdc_opt_strs[2005] =
/* 1785 */ "no-load-opts\0"
/* 1798 */ "no\0"
/* 1801 */ "NTPDC\0"
/* 1807 */ "ntpdc - vendor-specific NTPD control program - Ver. 4.2.8p16\n"
"Usage: %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [ host ...]\n\0"
/* 1938 */ "$HOME\0"
/* 1944 */ ".\0"
/* 1946 */ ".ntprc\0"
/* 1953 */ "https://bugs.ntp.org, bugs@ntp.org\0"
/* 1988 */ "\n\0"
-/* 1990 */ "ntpdc 4.2.8p16";
+/* 1990 */ "ntpdc 4.2.8p17";
/**
* ipv4 option description with
@@ -828,7 +828,7 @@ static void bogus_function(void) {
translate option names.
*/
/* referenced via ntpdcOptions.pzCopyright */
- puts(_("ntpdc 4.2.8p16\n\
+ puts(_("ntpdc 4.2.8p17\n\
Copyright (C) 1992-2023 The University of Delaware and Network Time Foundation, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the NTP License, copies of which\n\
@@ -897,14 +897,14 @@ implied warranty.\n"));
puts(_("load options from a config file"));
/* referenced via ntpdcOptions.pzUsageTitle */
- puts(_("ntpdc - vendor-specific NTPD control program - Ver. 4.2.8p16\n\
+ puts(_("ntpdc - vendor-specific NTPD control program - Ver. 4.2.8p17\n\
Usage: %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [ host ...]\n"));
/* referenced via ntpdcOptions.pzExplain */
puts(_("\n"));
/* referenced via ntpdcOptions.pzFullVersion */
- puts(_("ntpdc 4.2.8p16"));
+ puts(_("ntpdc 4.2.8p17"));
/* referenced via ntpdcOptions.pzFullUsage */
puts(_("<<<NOT-FOUND>>>"));
@@ -136,14 +136,14 @@ static char const ntpdc_opt_strs[2005] =
/* 1798 */ "no\0"
/* 1801 */ "NTPDC\0"
-/* 1807 */ "ntpdc - vendor-specific NTPD control program - Ver. 4.2.8p16\n"
+/* 1807 */ "ntpdc - vendor-specific NTPD control program - Ver. 4.2.8p17\n"
"Usage: %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [ host ...]\n\0"
/* 1938 */ "$HOME\0"